@@ -1,5 +1,5 @@
 # general stuff
-module_version = '1.0.5'
+module_version = '1.1.0'
 github_url = 'http://github.com/GMPavanLab/SwarmCG'
 gmx_path = 'gmx'
 
@@ -63,10 +63,9 @@ fct_guess_min_flat_diff_dihedrals_with_mult = 0.20 # flat minimum force constant
 handled_constraints_functions = [1]
 handled_bonds_functions = [1]
 handled_angles_functions = [1, 2]
-# handled_angles_functions = [2]
-handled_dihedrals_functions = [1, 2, 4, 9]
-# handled_dihedrals_functions = [1, 4, 9]
-dihedral_func_with_mult = [1, 4, 9] # these functions use 3 parameters, the last one being multiplicity (if it's omitted gromacs will use 1 by default, we reproduce this behavior)
+handled_dihedrals_functions = [1, 2, 4]
+dihedral_func_with_mult = [1, 4] # these functions use 3 parameters, the last one being multiplicity (if it's omitted gromacs will use 1 by default, we reproduce this behavior)
+# TODO: handle dihedral function 9 correctly so that different potentials can be stacked for the same beads -- this is the primary purpose of function 9 !! 
 
 # plots display parameters
 use_hists = False # hists are not implemented in a way that they will be displayed with left and right borders, as it is already the case for bonds
